<!---
Please read this!

Before opening a new issue, make sure to skim through the documentation
at http://km3py.pages.km3net.de/km3pipe
--->

### Summary

(Summarise the bug encountered concisely.)

### Environment

- KM3Pipe version (`km3pipe --version`):
- Python version (`python --version`):
- OS: (`uname -a`)

#### Additional information

(The following are optional but may be relevant.)

- HDF5 metadata (`h5info /path/to/relevant/file.h5`)
- ROOT file metadata (`JPrintMeta -f /path/to/relevant/file.root`):
- Jpp version (only if relevant, `JPrint -v`)

### Describe the current *bug* behavior

(What actually happens)

### Describe the expected *correct* behavior

(What you should see instead)

### Steps to reproduce

(How one can reproduce the issue - this is very important.)

### Relevant logs and/or screenshots

(Paste any relevant logs - please use code blocks (put the code between ```) to format console output, logs, and code as it's very hard to read otherwise.)

/label ~bug
